==> refcodes-remoting-3.0.6-sources.jar: org/refcodes/remoting/NoSuchProxyException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////
package org.refcodes.remoting;

/**
 * Thrown in case a proxy for a given type was requested but not any proxy
 * matched the requested type.
 */
public class NoSuchProxyException extends RemotingException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new no such proxy exception.
	 *
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public NoSuchProxyException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new no such proxy exception.
	 *
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public NoSuchProxyException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new no such proxy exception.
	 *
	 * @param message the message
	 * @param cause the cause
	 */
	public NoSuchProxyException( String message, Throwable cause ) {
		super( message, cause );
	}

	/**
	 * Instantiates a new no such proxy exception.
	 *
	 * @param message the message
	 */
	public NoSuchProxyException( String message ) {
		super( message );
	}

	/**
	 * Instantiates a new no such proxy exception.
	 *
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public NoSuchProxyException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * Instantiates a new no such proxy exception.
	 *
	 * @param cause the cause
	 */
	public NoSuchProxyException( Throwable cause ) {
		super( cause );
	}
}

==> refcodes-remoting-3.3.0-sources.jar: org/refcodes/remoting/NoSuchProxyException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////
package org.refcodes.remoting;

/**
 * Thrown in case a proxy for a given type was requested but not any proxy
 * matched the requested type.
 */
public class NoSuchProxyException extends RemotingException {

	private static final long serialVersionUID = 1L;

	/**
	 * {@inheritDoc}
	 */
	public NoSuchProxyException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * {@inheritDoc}
	 */
	public NoSuchProxyException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * {@inheritDoc}
	 */
	public NoSuchProxyException( String aMessage, Throwable aCause ) {
		super( aMessage, aCause );
	}

	/**
	 * {@inheritDoc}
	 */
	public NoSuchProxyException( String aMessage ) {
		super( aMessage );
	}

	/**
	 * {@inheritDoc}
	 */
	public NoSuchProxyException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * {@inheritDoc}
	 */
	public NoSuchProxyException( Throwable aCause ) {
		super( aCause );
	}
}
